@@ -29,7 +29,7 @@ if (!defined('LOG4PHP_DIR')) define('LOG4PHP_DIR', dirname(__FILE__));
  * <p>You need to recode methods to output messages in a different way.</p> 
  *
  * @author VxR <vxr@vxr.it>
- * @version $Revision: 2 $
+ * @version $Revision: 1544 $
  * @package log4php
  */
 class LoggerLog {
@@ -81,7 +81,8 @@ class LoggerLog {
      * @static
      * @since 0.3
      */
-    function error($message)
+    //function error($message)
+	static function error($message)		// C(2009/3/3)
     {
         trigger_error($message, E_USER_ERROR);
     }
@@ -93,7 +94,8 @@ class LoggerLog {
      * @static
      * @since 0.3
      */
-    function warn($message)
+    //function warn($message)
+	static function warn($message)		// C(2009/3/3)
     {
         trigger_error($message, E_USER_WARNING);
     }
