@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2013 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 5803 2013-03-07 11:09:50Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 5906 2013-04-05 10:51:35Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -175,6 +175,7 @@ INSERT INTO _page_info
 ('index',     'user',      'user',          false),
 ('index',     'event',     'event',         false),
 ('index',     'photo',     'photo',         false),
+('index',     'search',    'search',        false),
 ('index',     'contact',   '',              true),
 ('index',     'contact2',  '',              true),
 ('index',     'safe',      '',              true),
@@ -186,6 +187,7 @@ INSERT INTO _page_info
 ('m_index',   'user',      'user',          false),
 ('m_index',   'event',     'event',         false),
 ('m_index',   'photo',     'photo',         false),
+('m_index',   'search',    'search',        false),
 ('s_index',   'content',   'content',       false),
 ('s_index',   'shop',      'product',       false),
 ('s_index',   'shop_safe', '',              true),
@@ -195,6 +197,7 @@ INSERT INTO _page_info
 ('s_index',   'user',      'user',          false),
 ('s_index',   'event',     'event',         false),
 ('s_index',   'photo',     'photo',         false),
+('s_index',   'search',    'search',        false),
 ('s_index',   'contact',   '',              true),
 ('s_index',   'contact2',  '',              true),
 ('s_index',   'safe',      '',              true),
