@@ -8,7 +8,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: fckplugin.js 4791 2012-03-25 13:20:52Z fishbone $
+ * @version    SVN: $Id: fckplugin.js 5256 2012-09-30 08:44:13Z fishbone $
  * @link       http://www.magic3.org
  */
 // Toolbar button
@@ -629,7 +629,7 @@ FCKGoogleMap.prototype.BuildScript = function()
 	aScript.push(versionMarker);
 
 	if (this.WrapperClass !== '') aScript.push('document.write(\'<div class="' + this.WrapperClass + '">\'); //wrapper');
-	aScript.push('document.write(\'<div id="gmap' + this.number + '" style="width:' + this.width + 'px; height:' + this.height + 'px;">.<\\\/div>\');');
+	aScript.push('document.write(\'<div id="gmap' + this.number + '" style="width:' + this.width + 'px; height:' + this.height + 'px;display:none;">.<\\\/div>\');');
 	if (this.WrapperClass !== '') aScript.push('document.write(\'<\\\/div>\'); ');
 
 	aScript.push('function CreateGMap' + this.number + '() {');
@@ -652,10 +652,12 @@ FCKGoogleMap.prototype.BuildScript = function()
 	//aScript.push('					center:centerPos,');
 	//aScript.push('					mapTypeId: allMapTypes[' + this.mapType + '],');
 	aScript.push('	var opts = {	mapTypeControlOptions: {	mapTypeIds: allMapTypes } };');
-	aScript.push('	var map = new google.maps.Map(document.getElementById("gmap' + this.number + '"), opts);');
+	aScript.push('	var mapDiv = document.getElementById("gmap' + this.number + '");');
+	aScript.push('	var map = new google.maps.Map(mapDiv, opts);');
 	aScript.push('	map.setMapTypeId(allMapTypes[' + this.mapType + ']);');
 	aScript.push('	map.setCenter(new google.maps.LatLng(' + this.centerLat + ', ' + this.centerLon + '));');
 	aScript.push('	map.setZoom(' + this.zoom + ');');
+	aScript.push('	mapDiv.style.display = "";');
 
 	var aPoints = [];
 	for (var i = 0; i < this.markerPoints.length; i++)
