@@ -7,7 +7,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ckconfig.js 5963 2013-04-23 02:26:23Z fishbone $
+ * @version    SVN: $Id: ckconfig.js 5977 2013-04-30 22:24:32Z fishbone $
  * @link       http://www.magic3.org
  */
 // スタイルメニューの定義
@@ -139,8 +139,8 @@ CKEDITOR.editorConfig = function( config ) {
 	// 追加プラグインの設定
 	config.extraPlugins = 'youtube';
 	config.removePlugins = 'iframe';
-	config.allowedContent = true;
-	config.extraAllowedContent = 'iframe';
+	config.allowedContent = true;		// ACF(Advanced Content Filter)を使用しない。SCRIPT,IFRAMEタグ等許可。
+//	config.extraAllowedContent = 'iframe';
 //	config.autoGrow_maxHeight = 800;		// 指定サイズまで入力に合わせて拡大
 	
 	// KCFinderの設定
