@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfiglangWidgetContainer.php 4917 2012-05-23 09:44:57Z fishbone $
+ * @version    SVN: $Id: admin_mainConfiglangWidgetContainer.php 5124 2012-08-20 03:30:46Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainConfigsystemBaseWidgetContainer.php');
@@ -19,12 +19,12 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 class admin_mainConfiglangWidgetContainer extends admin_mainConfigsystemBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;	// システム情報取得用
-	private $defaultLang;	// デフォルト言語
 	private $acceptLanguage;	// アクセス可能言語
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	const CF_ACCEPT_LANGUAGE	= 'accept_language';	// アクセス可能言語
 	const ICON_PATH = '/images/system/flag/';		// 言語アイコンパス
+	const ITEM_HEAD_ACCEPT = 'item_accept';
+	const ITEM_HEAD_AVAILABLE = 'item_available';
 	
 	/**
 	 * コンストラクタ
@@ -36,7 +36,6 @@ class admin_mainConfiglangWidgetContainer extends admin_mainConfigsystemBaseWidg
 		
 		// DBオブジェクト作成
 		$this->db = new admin_mainDb();
-		//$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -73,7 +72,6 @@ class admin_mainConfiglangWidgetContainer extends admin_mainConfigsystemBaseWidg
 	 */
 	function createDetail($request)
 	{
-		$this->defaultLang		= $this->gEnv->getDefaultLanguage();
 		$act = $request->trimValueOf('act');
 
 		if ($act == 'update'){		// 更新のとき
@@ -83,21 +81,25 @@ class admin_mainConfiglangWidgetContainer extends admin_mainConfigsystemBaseWidg
 			if ($this->getMsgCount() == 0){
 				$listedItem = explode(',', $request->trimValueOf('seriallist'));
 				$selItems = array();
+				$ret = true;
 				for ($i = 0; $i < count($listedItem); $i++){
-					// 項目がチェックされているかを取得
-					$itemName = 'item' . $i . '_selected';
+					// アクセス可能項目がチェックされているかを取得
+					$itemName = self::ITEM_HEAD_ACCEPT . $i;
 					$itemValue = ($request->trimValueOf($itemName) == 'on') ? 1 : 0;
-				
-					if ($itemValue){		// チェック項目
-						$selItems[] = $listedItem[$i];
-					}
+					if ($itemValue) $selItems[] = $listedItem[$i];	// チェック項目
+					
+					// メニューからの選択可否を更新
+					$itemName = self::ITEM_HEAD_AVAILABLE . $i;
+					$itemValue = ($request->trimValueOf($itemName) == 'on') ? 1 : 0;
+					$ret = $this->db->updateLangStatus($listedItem[$i], $itemValue);
+					if (!$ret) break;
 				}
 				$langStr = '';
 				if (!empty($selItems)) $langStr = implode($selItems, ',');
 				
 				// アクセス可能言語を更新
-				//$ret = $this->sysDb->updateSystemConfig(self::CF_ACCEPT_LANGUAGE, $langStr);
-				$ret = $this->_db->updateSystemConfig(self::CF_ACCEPT_LANGUAGE, $langStr);
+				if ($ret) $ret = $this->_db->updateSystemConfig(self::CF_ACCEPT_LANGUAGE, $langStr);
+				
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				} else {
@@ -125,24 +127,28 @@ class admin_mainConfiglangWidgetContainer extends admin_mainConfigsystemBaseWidg
 	{
 		$langId = $fetchedRow['ln_id'];		// 言語ID
 		
-		// アクセス許可状態を取得
-		$accept = '';
-		if (in_array($langId, $this->acceptLanguage)) $accept = 'checked';
-
 		$name = $fetchedRow['ln_name'];
-		if ($langId == $this->defaultLang) $name .= '(デフォルト)';
+		if ($langId == $this->gEnv->getDefaultLanguage()) $name .= '(デフォルト)';
 		
 		// 言語アイコン
 		$iconTitle = $fetchedRow['ln_name'];
 		$iconUrl = $this->gEnv->getRootUrl() . self::ICON_PATH . $fetchedRow['ln_image_filename'];		// 画像ファイル
 		$iconTag = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 		
+		// アクセス許可状態を取得
+		$accept = '';
+		if (in_array($langId, $this->acceptLanguage)) $accept = 'checked';
+		
+		$available = '';
+		if ($fetchedRow['ln_available']) $available = 'checked';
+		
 		$row = array(
 			'image'		=> $iconTag,				// 言語アイコン
 			'index'		=> $index,
 			'value'		=> $this->convertToDispString($langId),			// 言語値
 			'name'		=> $this->convertToDispString($name),			// 言語名
-			'accept'	=> $accept														// アクセス許可状態
+			'accept'	=> $accept,										// アクセス許可状態
+			'available'	=> $available									// 利用可(管理画面)
 		);
 		$this->tmpl->addVars('lang_list', $row);
 		$this->tmpl->parseTemplate('lang_list', 'a');
