@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_menu3WidgetContainer.php 5735 2013-02-26 01:01:34Z fishbone $
+ * @version    SVN: $Id: admin_menu3WidgetContainer.php 5858 2013-03-25 01:04:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -22,6 +22,7 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 	protected $cssFilePath;			// CSSファイル
 	protected $themeFilePath;		// テーマファイル
 	protected $contentMenu;			// コンテンツ編集メニュー
+	protected $subContentMenu;			// サブコンテンツ編集メニュー
 	//const DEFAULT_SITE_NAME = 'サイト名未設定';
 	const DEFAULT_CSS_FILE = '/default.css';		// CSSファイル
 	const DEFAULT_NAV_ID = 'admin_menu';			// ナビゲーションメニューID
@@ -41,6 +42,7 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 	const PREVIEW_ICON_SIZE = 24;			// プレビューアイコンサイズ
 	const HELP_TITLE = 'ヘルプ';
 	const MENU_TITLE_CONTENT = 'コンテンツ管理';		// コンテンツ編集メニューのタイトル
+	const MENU_TITLE_SUB_CONTENT = 'サブコンテンツ管理';		// サブコンテンツ編集メニューのタイトル
 	
 	/**
 	 * コンストラクタ
@@ -229,6 +231,7 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 			
 			// 運用中のコンテンツを取得
 			$this->contentMenu = $this->getContentMenu();			// コンテンツ編集メニュー項目取得
+			$this->subContentMenu = $this->getSubContentMenu();			// サブコンテンツ編集メニュー
 			
 			// サイトプレビュー
 			$previewTag = $this->createSitePreviewTag();
@@ -361,6 +364,37 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 		}
 		return $menuItems;
 	}
+	/**
+	 * サブコンテンツ編集メニュー項目を取得
+	 *
+	 * @return string			メニュー項目データ
+	 */
+	function getSubContentMenu()
+	{
+		$menuItems = array(array(), array(), array());
+		$pageIdArray = array($this->gEnv->getDefaultPageId(), $this->gEnv->getDefaultMobilePageId(), $this->gEnv->getDefaultSmartphonePageId());
+		$ret = $this->db->getEditSubWidgetOnPage($pageIdArray, $rows);
+		if ($ret){
+			$rowCount = count($rows);
+			for ($i = 0; $i < $rowCount; $i++){
+				$row = $rows[$i];
+				switch ($row['pd_id']){
+					case $pageIdArray[0]:
+					default:
+						$index = 0;
+						break;
+					case $pageIdArray[1]:
+						$index = 1;
+						break;
+					case $pageIdArray[2]:
+						$index = 2;
+						break;
+				}
+				$menuItems[$index][] = $row;
+			}
+		}
+		return $menuItems;
+	}
 	/**
 	 * コンテンツ編集メニュー作成
 	 *
@@ -369,55 +403,96 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 	 */
 	function createContentMenu($deviceType)
 	{
-		$menu = $this->contentMenu[$deviceType];
-		if (empty($menu)) return '';
+		$menu = $this->contentMenu[$deviceType];		// コンテンツ編集メニュー
+		$subMenu = $this->subContentMenu[$deviceType];	// サブコンテンツ編集メニュー
+		if (empty($menu) && empty($subMenu)) return '';
 		
 		$menuTag .= '<div class="ldd_submenu ui-widget-header">';
 		$menuTag .= '<table border="0" cellpadding="0" cellspacing="0" align="center"><tr valign="top"><td>';
-		$menuTag .= '<div class="m3toppage_menu">';
-		$menuTag .= '<div class="ui-state-default ui-priority-primary ui-corner-tl ui-corner-tr"><span>' . self::MENU_TITLE_CONTENT . '</span></div>';
-		$menuTag .= '<ul class="ui-widget-content ui-corner-bl ui-corner-br">';
 		
-		for ($i = 0; $i < count($menu); $i++){
-			$contentType = $menu[$i]['wd_type'];
-			$widgetId = $menu[$i]['wd_id'];
+		// コンテンツ編集メニュー
+		if (!empty($menu)){
+			$menuTag .= '<div class="m3toppage_menu">';
+			$menuTag .= '<div class="ui-state-default ui-priority-primary ui-corner-tl ui-corner-tr"><span>' . self::MENU_TITLE_CONTENT . '</span></div>';
+			$menuTag .= '<ul class="ui-widget-content ui-corner-bl ui-corner-br">';
+		
+			for ($i = 0; $i < count($menu); $i++){
+				$widgetId = $menu[$i]['wd_id'];
+				$title = $this->getCurrentLangString($menu[$i]['wd_content_name']);		// ウィジェットのコンテンツ名を取得
+				
+				if (empty($title)){
+					// コンテンツ単位でタイトルを取得
+					$contentType = $menu[$i]['wd_type'];
+					switch ($contentType){
+						case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
+							$title = '汎用コンテンツ';
+							break;
+						case M3_VIEW_TYPE_PRODUCT:				// 商品情報(Eコマース)
+							$title = '商品情報';
+							break;
+						case M3_VIEW_TYPE_BBS:					// BBS
+							$title = 'BBS';
+							break;
+						case M3_VIEW_TYPE_BLOG:				// ブログ
+							$title = 'ブログ';
+							break;
+						case M3_VIEW_TYPE_WIKI:				// wiki
+							$title = 'wiki';
+							break;
+						case M3_VIEW_TYPE_USER:				// ユーザ作成コンテンツ
+							$title = 'ユーザ作成コンテンツ';
+							break;
+						case M3_VIEW_TYPE_EVENT:				// イベント
+							$title = 'イベント';
+							break;
+						case M3_VIEW_TYPE_PHOTO:				// フォトギャラリー
+							$title = 'フォトギャラリー';
+							break;
+						default:
+							$title = '';
+							break;
+					}
+				}
+				if (empty($title)) $title = $menu[$i]['wd_name'];		// コンテンツ名が取得できないときはウィジェット名を設定
+				if (empty($title)) continue;
 			
-			// コンテンツ単位でタイトルを取得
-			switch ($contentType){
-				case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
-					$title = '汎用コンテンツ';
-					break;
-				case M3_VIEW_TYPE_PRODUCT:				// 商品情報(Eコマース)
-					$title = '商品情報';
-					break;
-				case M3_VIEW_TYPE_BBS:					// BBS
-					$title = 'BBS';
-					break;
-				case M3_VIEW_TYPE_BLOG:				// ブログ
-					$title = 'ブログ';
-					break;
-				case M3_VIEW_TYPE_WIKI:				// wiki
-					$title = 'wiki';
-					break;
-				case M3_VIEW_TYPE_USER:				// ユーザ作成コンテンツ
-					$title = 'ユーザ作成コンテンツ';
-					break;
-				case M3_VIEW_TYPE_EVENT:				// イベント
-					$title = 'イベント';
-					break;
-				case M3_VIEW_TYPE_PHOTO:				// フォトギャラリー
-					$title = 'フォトギャラリー';
-					break;
-				default:
-					$title = '';
-					break;
+				$menuTag .= '<li ><a href="#" onclick="m3ShowConfigWindow(\'' . $widgetId . '\', 0, 0);return false;"><span >' . $this->convertToDispString($title) . '</span></a></li>';
 			}
-			if (empty($title)) continue;
-			
-			$menuTag .= '<li ><a href="#" onclick="m3ShowConfigWindow(\'' . $widgetId . '\', 0, 0);return false;"><span >' . $this->convertToDispString($title) . '</span></a></li>';
+			$menuTag .= '</ul>';
+			$menuTag .= '</div>';
 		}
-		$menuTag .= '</ul>';
-		$menuTag .= '</div>';
+		
+		// サブコンテンツ編集メニュー
+		if (!empty($subMenu)){
+			$menuTag .= '<div class="m3toppage_menu">';
+			$menuTag .= '<div class="ui-state-default ui-priority-primary ui-corner-tl ui-corner-tr"><span>' . self::MENU_TITLE_SUB_CONTENT . '</span></div>';
+			$menuTag .= '<ul class="ui-widget-content ui-corner-bl ui-corner-br">';
+		
+			for ($i = 0; $i < count($subMenu); $i++){
+				$widgetId = $subMenu[$i]['wd_id'];
+				$title = $this->getCurrentLangString($subMenu[$i]['wd_content_name']);		// ウィジェットのコンテンツ名を取得
+				
+				if (empty($title)){
+					// コンテンツ単位でタイトルを取得
+					$contentType = $subMenu[$i]['wd_content_type'];
+					switch ($contentType){
+						case 'banner':				// バナー
+							$title = 'バナー';
+							break;
+						default:
+							$title = '';
+							break;
+					}
+				}
+				if (empty($title)) $title = $subMenu[$i]['wd_name'];		// サブコンテンツ名が取得できないときはウィジェット名を設定
+				if (empty($title)) continue;
+			
+				$menuTag .= '<li ><a href="#" onclick="m3ShowConfigWindow(\'' . $widgetId . '\', 0, 0);return false;"><span >' . $this->convertToDispString($title) . '</span></a></li>';
+			}
+			$menuTag .= '</ul>';
+			$menuTag .= '</div>';
+		}
+		
 		$menuTag .= '</td></tr></table>';
 		$menuTag .= '</div>';
 		return $menuTag;
