@@ -8,26 +8,19 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainBaseWidgetContainer.php 3953 2011-01-24 04:33:43Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainBaseWidgetContainer.php 5145 2012-08-29 13:21:42Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() . '/blog_mainCommonDef.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/blog_mainDb.php');
 
 class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 {
-	protected $_db;			// DB接続オブジェクト
-	protected $_configArray;		// BBS定義値
-	const CF_RECEIVE_COMMENT		= 'receive_comment';		// コメントを受け付けるかどうか
-	const CF_RECEIVE_TRACKBACK		= 'receive_trackback';		// トラックバックを受け付けるかどうか
-	const CF_ENTRY_VIEW_COUNT		= 'entry_view_count';			// 記事表示数
-	const CF_ENTRY_VIEW_ORDER		= 'entry_view_order';			// 記事表示方向
-	const CF_MAX_COMMENT_LENGTH		= 'comment_max_length';		// コメント最大文字数
-	const CF_USE_MULTI_BLOG		= 'use_multi_blog';		// マルチブログ機能を使用するかどうか
-	const CF_MULTI_BLOG_TOP_CONTENT	= 'multi_blog_top_content';		// マルチブログ時のトップコンテンツ
-	const CF_CATEGORY_COUNT			= 'category_count';		// カテゴリ数
+	protected static $_mainDb;			// DB接続オブジェクト
+	protected static $_configArray;		// ブログ定義値
 	const DEFAULT_COMMENT_LENGTH	= 300;				// デフォルトのコメント最大文字数
 	const DEFAULT_CATEGORY_COUNT	= 2;				// デフォルトのカテゴリ数
 	
@@ -36,6 +29,9 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 	const CALENDAR_LANG_FILE = '/jscalendar-1.0/lang/calendar-ja.js';	// カレンダー言語ファイル
 	const CALENDAR_SETUP_FILE = '/jscalendar-1.0/calendar-setup.js';	// カレンダーセットアップファイル
 	const CALENDAR_CSS_FILE = '/jscalendar-1.0/calendar-win2k-1.css';		// カレンダー用CSSファイル
+	// 画面
+	const TASK_CONFIG = 'config';								// その他設定
+	const TASK_HISTORY = 'history';							// ブログ記事履歴
 	
 	/**
 	 * コンストラクタ
@@ -45,14 +41,11 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 		// 親クラスを呼び出す
 		parent::__construct();
 		
-		// サブウィジェット起動のときだけ初期処理実行
-		if ($this->gEnv->getIsSubWidget()){
-			// DBオブジェクト作成
-			$this->_db = new blog_mainDb();
+		// DBオブジェクト作成
+		if (!isset(self::$_mainDb)) self::$_mainDb = new blog_mainDb();
 		
-			// BBS定義を読み込む
-			$this->_loadConfig();
-		}
+		// ブログ定義を読み込む
+		if (!isset(self::$_configArray)) self::$_configArray = blog_mainCommonDef::loadConfig(self::$_mainDb);
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -77,6 +70,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 		switch ($task){
 			case 'entry':		// ブログ記事
 			case 'entry_detail':	// ブログ記事詳細
+			case self::TASK_HISTORY:							// ブログ記事履歴
 				$linkList = ' &gt;&gt; ブログ記事 &gt;&gt; 記事一覧';// パンくずリスト
 				break;
 			case 'comment':		// ブログ記事コメント
@@ -87,7 +81,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 			case 'user_detail':		// ユーザ管理(詳細)
 				$linkList = ' &gt;&gt; ユーザ管理 &gt;&gt; ユーザ一覧';// パンくずリスト
 				break;
-			case 'config':		// ブログ設定
+			case self::TASK_CONFIG:		// ブログ設定
 				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; ブログ設定';// パンくずリスト
 				break;
 			case 'category':		// カテゴリ設定
@@ -112,8 +106,9 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 		$link = $baseUrl . '&task=entry';
 		if ($task == 'entry' ||
 			$task == 'entry_detail' ||
+			$task == self::TASK_HISTORY ||	// ブログ記事履歴
 			$task == 'comment' ||		// ブログ記事コメント管理
-			$task == 'comment_detail'){
+			$task == 'comment_detail'){							
 			$current = 'id="current"';
 		}
 		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>ブログ記事</span></a></li>' . M3_NL;
@@ -125,7 +120,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 			$task == 'category_detail' ||		// カテゴリ設定
 			$task == 'blogid' ||		// マルチブログ
 			$task == 'blogid_detail' ||		// マルチブログ詳細
-			$task == 'config'){		// ブログ設定
+			$task == self::TASK_CONFIG){		// ブログ設定
 			$current = 'id="current"';
 		}
 		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>基本設定</span></a></li>' . M3_NL;
@@ -140,13 +135,14 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 
 		if ($task == 'entry' ||		// ブログ記事管理
 			$task == 'entry_detail' ||
+			$task == self::TASK_HISTORY ||	// ブログ記事履歴
 			$task == 'comment' ||		// ブログ記事コメント管理
 			$task == 'comment_detail'){
 			
 			// ブログ記事一覧
 			$current = '';
 			$link = $baseUrl . '&task=entry';
-			if ($task == 'entry' || $task == 'entry_detail') $current = 'id="current"';
+			if ($task == 'entry' || $task == 'entry_detail' || $task == self::TASK_HISTORY) $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>記事一覧</span></a></li>' . M3_NL;
 			
 			// ブログ記事コメント一覧
@@ -158,7 +154,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 			$task == 'category_detail' ||		// カテゴリ設定
 			$task == 'blogid' ||		// マルチブログ
 			$task == 'blogid_detail' ||		// マルチブログ詳細
-			$task == 'config'){		// ブログ設定
+			$task == self::TASK_CONFIG){		// ブログ設定
 			
 			// カテゴリ設定
 			$current = '';
@@ -175,7 +171,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 			// その他設定
 			$current = '';
 			$link = $baseUrl . '&task=config';
-			if ($task == 'config') $current = 'id="current"';
+			if ($task == self::TASK_CONFIG) $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>ブログ設定</span></a></li>' . M3_NL;
 		}
 		
@@ -188,27 +184,5 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 		$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
 		$this->tmpl->addVar("_widget", "menu_items", $outputText);
 	}
-	/**
-	 * ブログ定義値をDBから取得
-	 *
-	 * @return bool			true=取得成功、false=取得失敗
-	 */
-	function _loadConfig()
-	{
-		$this->_configArray = array();
-
-		// ブログ定義を読み込み
-		$ret = $this->_db->getAllConfig($rows);
-		if ($ret){
-			// 取得データを連想配列にする
-			$configCount = count($rows);
-			for ($i = 0; $i < $configCount; $i++){
-				$key = $rows[$i]['bg_id'];
-				$value = $rows[$i]['bg_value'];
-				$this->_configArray[$key] = $value;
-			}
-		}
-		return $ret;
-	}
 }
 ?>
