@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 5147 2012-09-02 13:15:02Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 5235 2012-09-21 00:55:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_blog_mainBaseWidgetContainer.php');
@@ -134,7 +134,12 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		
 		$act = $request->trimValueOf('act');
 		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
-		if (empty($this->langId)) $this->langId = $defaultLangId;			// 言語が選択されていないときは、デフォルト言語を設定	
+		if (empty($this->langId)) $this->langId = $defaultLangId;			// 言語が選択されていないときは、デフォルト言語を設定
+		if ($this->gEnv->isAdminDirAccess()){		// 管理画面へのアクセスの場合
+			$this->blogId = null;	// デフォルトブログ(ブログID空)を含むすべてのブログ記事にアクセス可能
+		} else {
+			$this->blogId = $request->trimValueOf(M3_REQUEST_PARAM_BLOG_ID);		// 所属ブログ
+		}
 		
 		// ##### 検索条件 #####
 		$pageNo = $request->trimValueOf('page');				// ページ番号
@@ -194,7 +199,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					// ##### サムネールの削除 #####
 					for ($i = 0; $i < count($delEntryInfo); $i++){
 						$infoObj = $delEntryInfo[$i];
-						$ret = $this->removeThumbnail($infoObj->entryId);
+						$ret = blog_mainCommonDef::removeThumbnail($infoObj->entryId);
 						
 						if (!empty($infoObj->thumb)){
 							$oldFiles = explode(';', $infoObj->thumb);
@@ -230,7 +235,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		if (!empty($search_endDt)) $endDt = $this->getNextDay($search_endDt);
 		
 		// 総数を取得
-		$totalCount = self::$_mainDb->getEntryItemCount($search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId);
+		$totalCount = self::$_mainDb->getEntryItemCount($search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, $this->blogId);
 
 		// 表示するページ番号の修正
 		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
@@ -252,7 +257,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		}
 		
 		// 記事項目リストを取得
-		self::$_mainDb->searchEntryItems($maxListCount, $pageNo, $search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, array($this, 'itemListLoop'));
+		self::$_mainDb->searchEntryItems($maxListCount, $pageNo, $search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, array($this, 'itemListLoop'), $this->blogId);
 		if (count($this->serialArray) <= 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');// 投稿記事がないときは、一覧を表示しない
 		
 		// カテゴリーメニューを作成
@@ -303,7 +308,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		$this->entryId = $request->trimValueOf('entryid');		// 記事エントリーID
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
 //		if (empty($this->serialNo)) $this->serialNo = 0;
-		$this->blogId = $request->trimValueOf('blogid');		// 所属ブログ
+		$this->blogId = $request->trimValueOf(M3_REQUEST_PARAM_BLOG_ID);		// 所属ブログ
 		$name = $request->trimValueOf('item_name');
 		$entry_date = $request->trimValueOf('item_entry_date');		// 投稿日
 		$entry_time = $request->trimValueOf('item_entry_time');		// 投稿時間
@@ -447,9 +452,9 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 						$status		= $row['be_status'];
 				
 						if ($status == 2){		// 公開の場合
-							$ret = $this->createThumbnail($html, $entryId, $updateDt);
+							$ret = blog_mainCommonDef::createThumbnail($html, $entryId, $updateDt);
 						} else {
-							$ret = $this->removeThumbnail($entryId);
+							$ret = blog_mainCommonDef::removeThumbnail($entryId);
 						}
 					}
 					
@@ -547,9 +552,9 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 						$status		= $row['be_status'];
 				
 						if ($status == 2){		// 公開の場合
-							$ret = $this->createThumbnail($html, $entryId, $updateDt);
+							$ret = blog_mainCommonDef::createThumbnail($html, $entryId, $updateDt);
 						} else {
-							$ret = $this->removeThumbnail($entryId);
+							$ret = blog_mainCommonDef::removeThumbnail($entryId);
 						}
 					}
 					
@@ -596,7 +601,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$this->setGuidanceMsg('データを削除しました');
 					
 					// ##### サムネールの削除 #####
-					$ret = $this->removeThumbnail($this->entryId);
+					$ret = blog_mainCommonDef::removeThumbnail($this->entryId);
 					
 					// サムネールを削除
 					if (!empty($row['be_thumb_filename'])){
@@ -634,7 +639,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$this->setGuidanceMsg('データを削除しました');
 					
 					// ##### サムネールの削除 #####
-					$ret = $this->removeThumbnail($this->entryId);
+					$ret = blog_mainCommonDef::removeThumbnail($this->entryId);
 					
 					// キャッシュデータのクリア
 					$this->clearCacheBySerial($this->serialNo);
@@ -679,7 +684,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				$entry_date = date("Y/m/d");		// 投稿日
 				$entry_time = date("H:i:s");		// 投稿時間
 				$showComment = 1;				// コメントを表示するかどうか
-				$receiveComment = 0;		// コメントを受け付けるかどうか
+				$receiveComment = 1;		// コメントを受け付けるかどうか
 			}
 		}
 		
@@ -1060,75 +1065,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			$this->clearCache($urlParam);
 		}
 	}
-	/**
-	 * サムネール画像を作成
-	 *
-	 * @param string $srcHtml		画像を検索するHTML
-	 * @param int    $entryId		ブログ記事ID
-	 * @param timestamp $updateDt	記事の更新日付
-	 * @return string				画像URL
-	 */
-	function createThumbnail($srcHtml, $entryId, $updateDt)
-	{
-		// サムネール
-		$thumbUrl	= $this->gInstance->getImageManager()->getDefaultThumbUrl(M3_VIEW_TYPE_BLOG, $entryId);
-		$thumbPath	= $this->gInstance->getImageManager()->getDefaultThumbPath(M3_VIEW_TYPE_BLOG, $entryId);
-
-		// ファイルと日時をチェック
-		$createImage = true;
-		if (file_exists($thumbPath) && strtotime($updateDt) < filemtime($thumbPath)){
-			$createImage = false;
-		}
-		
-		// サムネールを作成
-		if ($createImage){
-			// ブログ記事から最初の画像を取得
-			// 読み飛ばしが指定されている場合は飛ばす
-			$regex = '/<img[^<]*?src\s*=\s*[\'"]+(.+?)[\'"]+[^>]*?>/si';
-			if (preg_match($regex, $srcHtml, $matches)){		// 画像が取得できたとき
-				// 相対パスを取得
-				$imageUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $matches[1]);
-				if (strStartsWith($imageUrl, '/')){
-					$relativePath = $this->gEnv->getRelativePathToSystemRootUrl($this->gEnv->getDocumentRootUrl() . $imageUrl);
-				} else {
-					if ($this->gEnv->isSystemUrlAccess($imageUrl)){		// システム内のファイルのとき
-						$relativePath = $this->gEnv->getRelativePathToSystemRootUrl($imageUrl);
-					}
-				}
-				
-				if (strStartsWith($relativePath, '/' . M3_DIR_NAME_RESOURCE . '/')){		// リソースディレクトリ以下のリソースのみ変換
-					$imagePath = $this->gEnv->getSystemRootPath() . $relativePath;		// 元画像のファイルパス
-					
-					// 画像格納用のディレクトリ作成
-					$destDir = dirname($thumbPath);
-					if (!file_exists($destDir)) mkdir($destDir, M3_SYSTEM_DIR_PERMISSION, true/*再帰的*/);
-
-					// サムネール作成
-					$ret = $this->gInstance->getImageManager()->createDefaultThumb(M3_VIEW_TYPE_BLOG, $entryId, $imagePath);
-					if (!$ret) $thumbUrl = '';
-				} else {
-					$thumbUrl = '';
-				}
-			} else {		// 画像が取得できないとき
-				// サムネール画像を削除
-				if (file_exists($thumbPath)) @unlink($thumbPath);
-				$thumbUrl = '';
-			}
-		}
-		return $thumbUrl;
-	}
-	/**
-	 * サムネール画像を削除
-	 *
-	 * @param int    $entryId		ブログ記事ID
-	 * @return bool					true=成功、false=失敗
-	 */
-	function removeThumbnail($entryId)
-	{
-		$thumbPath	= $this->gInstance->getImageManager()->getDefaultThumbPath(M3_VIEW_TYPE_BLOG, $entryId);
-		if (file_exists($thumbPath)) @unlink($thumbPath);
-		return true;
-	}
 	/**
 	 * ユーザ定義フィールドを作成
 	 *
