@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: chacha_mainMypageWidgetContainer.php 3352 2010-07-08 02:59:39Z fishbone $
+ * @version    SVN: $Id: chacha_mainMypageWidgetContainer.php 3367 2010-07-11 11:45:28Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/chacha_mainBaseWidgetContainer.php');
@@ -19,6 +19,8 @@ class chacha_mainMypageWidgetContainer extends chacha_mainBaseWidgetContainer
 {
 	private $threadStyle;	// スレッド部表示スタイル
 	private $isExistsMessage;	// メッセージが存在するかどうか
+	private $isExistsNextPage;	// 次のページがあるかどうか
+	private $messageCount;		// メッセージ総数
 	const THREAD_ID_LENGTH = 5;	// スレッドIDの長さ
 	
 	/**
@@ -55,6 +57,8 @@ class chacha_mainMypageWidgetContainer extends chacha_mainBaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		$act = $request->trimValueOf('act');
+		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
+		if (empty($pageNo)) $pageNo = 1;
 		$postTicket = $request->trimValueOf('ticket');		// POST確認用
 		$memberId = $request->trimValueOf(self::URL_PARAM_MEMBER_ID);	// 会員ID
 		$message = $request->trimValueOf('message');		// 投稿メッセージ
@@ -118,9 +122,8 @@ class chacha_mainMypageWidgetContainer extends chacha_mainBaseWidgetContainer
 			$this->tmpl->addVar("thread_area", "image", $imageTag);		// 画像
 			
 			// 投稿文を作成
-			$limit = $this->_configArray[self::CF_MESSAGE_COUNT_MYPAGE];		// 最大項目数
-			$page = 1;
-			$this->_db->getThreadByMemberId($this->_boardId, $memberId, $limit, $page, array($this, 'itemsLoop'));
+			$this->messageCount = $this->_configArray[self::CF_MESSAGE_COUNT_MYPAGE];		// 最大項目数
+			$this->_db->getThreadByMemberId($this->_boardId, $memberId, $this->messageCount, $pageNo, array($this, 'itemsLoop'), true);
 			
 			// 画面にデータを埋め込む
 			$this->tmpl->addVar("thread_area", "name", $this->convertToDispString($row['mb_name']));				// ユーザ名
@@ -142,6 +145,19 @@ class chacha_mainMypageWidgetContainer extends chacha_mainBaseWidgetContainer
 				
 				$this->tmpl->setAttribute('message_list', 'visibility', 'hidden');
 			}
+			// ページ遷移用リンク
+			$pageLink = '';
+			if ($pageNo > 1){			// 前のページがあるとき
+				$foreLink = $this->convertUrlToHtmlEntity($this->getUrl($this->_currentPageUrl . '&' . self::URL_PARAM_MEMBER_ID . '=' . $memberId . '&page=' . ($pageNo -1), true));
+				$pageLink .= '<a href="' . $foreLink . '"><b>前へ</b></a>';
+			}
+			if ($this->isExistsNextPage){	// 次のページがあるとき
+				if (!empty($pageLink)) $pageLink .= '&nbsp;&nbsp;';
+				$nextLink = $this->convertUrlToHtmlEntity($this->getUrl($this->_currentPageUrl . '&' . self::URL_PARAM_MEMBER_ID . '=' . $memberId . '&page=' . ($pageNo +1), true));
+				$pageLink .= '<a href="' . $nextLink . '"><b>次へ</b></a>';
+			}
+			$this->tmpl->addVar("_widget", "page_link", $pageLink);
+			
 			// リンク作成
 			$profileLink = $this->convertUrlToHtmlEntity($this->getUrl($this->_currentPageUrl . '&task=' . self::TASK_PROFILE . '&' . self::URL_PARAM_MEMBER_ID . '=' . $memberId, true));
 			$this->tmpl->setAttribute('top_link_area', 'visibility', 'visible');
@@ -157,7 +173,7 @@ class chacha_mainMypageWidgetContainer extends chacha_mainBaseWidgetContainer
 		$threadColor = $this->_configArray[self::CF_THREAD_COLOR];		// スレッド表示部背景色
 		if (empty($threadColor)) $threadColor = $this->_configArray[self::CF_INNER_BG_COLOR];		// デフォルトの内枠背景色
 		if (!empty($threadColor)) $this->threadStyle .= 'background-color:' . $threadColor . ';';
-		$this->tmpl->addVar("thread_area", "thread_style", $this->threadStyle);
+		$this->tmpl->addVar("_widget", "thread_style", $this->threadStyle);
 		
 		// 画面にデータを埋め込む
 		$this->tmpl->addVar("add_area", "message", $message);
@@ -172,7 +188,11 @@ class chacha_mainMypageWidgetContainer extends chacha_mainBaseWidgetContainer
 	 */
 	function itemsLoop($index, $fetchedRow)
 	{
-		// ##### メッセージ部分を作成 #####
+		// 最大表示数を超えたときは終了
+		if ($index >= $this->messageCount){
+			$this->isExistsNextPage = true;				// 次のページあり
+			return false;
+		}
 		
 		// 日付作成
 		$weekDay = array('日', '月', '火', '水', '木', '金', '土');
