@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_contactus_customWidgetContainer.php 2248 2009-08-24 05:22:21Z fishbone $
+ * @version    SVN: $Id: admin_contactus_customWidgetContainer.php 2319 2009-09-16 01:10:12Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -262,9 +262,18 @@ class admin_contactus_customWidgetContainer extends BaseAdminWidgetContainer
 		// ボタンの表示制御
 		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
+			
+			// プレビューボタン作成
+			$this->tmpl->addVar("_widget", "preview_disabled", 'disabled ');// 「プレビュー」ボタン
 		} else {
 			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');// 「更新」ボタン
 			
+			// このウィジェットがマップされているページサブIDを取得
+			$subPageId = $this->gPage->getPageSubIdByWidget($this->gEnv->getDefaultPageId(), $this->gEnv->getCurrentWidgetId(), $defConfigId);
+			$previewUrl = $this->gEnv->getDefaultUrl();
+			if (!empty($subPageId)) $previewUrl .= '?sub=' . $subPageId;
+			$this->tmpl->addVar("_widget", "preview_url", $this->getUrl($previewUrl));
+			
 			// ヘルプの追加
 			$this->convertHelp('update_button');
 		}
