@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_slide_menuWidgetContainer.php 2860 2010-02-16 05:25:46Z fishbone $
+ * @version    SVN: $Id: admin_slide_menuWidgetContainer.php 4944 2012-06-07 23:47:16Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -19,7 +19,6 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/slide_menuDb.php');
 class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();			// 表示中のシリアル番号
 	private $langId;
@@ -50,7 +49,6 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 		
 		// DBオブジェクト作成
 		$this->db = new slide_menuDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 		
 		// メニュータイプ
 		$this->menuTypeDef = array(	array(	'name' => 'スライド',		'value' => 'slide'),
@@ -116,7 +114,6 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 		$this->configId = $request->trimValueOf('item_id');		// 定義ID
 		if (empty($this->configId)) $this->configId = $defConfigId;		// 呼び出しウィンドウから引き継いだ定義ID
 		$name	= $request->trimValueOf('item_name');			// ヘッダタイトル
-		$limitUser = ($request->trimValueOf('item_limituser') == 'on') ? 1 : 0;		// ユーザを制限するかどうか
 		$this->menuType = $request->trimValueOf('item_menu_type');			// メニュータイプ
 		if (empty($this->menuType)) $this->menuType = self::DEFAULT_MENU_TYPE;
 		$this->menuSpeed = $request->trimValueOf('item_menu_speed');			// メニュー表示速度
@@ -143,7 +140,6 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 				$newObj = new stdClass;
 				$newObj->menuId	= $this->menuId;		// メニューID
 				$newObj->name	= $name;// 表示名
-				$newObj->limitUser = $limitUser;		// ユーザを制限するかどうか
 				$newObj->menuType = $this->menuType;			// メニュータイプ
 				$newObj->menuSpeed = $this->menuSpeed;			// メニュー表示速度
 				$newObj->defaultNo = $this->defaultNo;			// デフォルトの項目番号
@@ -168,7 +164,6 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 				$ret = $this->getPageDefParam($defSerial, $defConfigId, $this->paramObj, $this->configId, $targetObj);
 				if ($ret){
 					// ウィジェットオブジェクト更新
-					$targetObj->limitUser = $limitUser;					// ユーザを制限するかどうか
 					$targetObj->menuType = $this->menuType;			// メニュータイプ
 					$targetObj->menuSpeed = $this->menuSpeed;			// メニュー表示速度
 					$targetObj->defaultNo = $this->defaultNo;			// デフォルトの項目番号
@@ -196,7 +191,6 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 			$this->tmpl->setAttribute('item_name_visible', 'visibility', 'visible');// 名前入力フィールド表示
 			$name = $this->createDefaultName();			// デフォルト登録項目名
 			$this->cssId = $this->createDefaultCssId();	// CSS用ID
-			$limitUser = 0;					// ユーザを制限するかどうか
 			$this->menuType = self::DEFAULT_MENU_TYPE;			// メニュータイプ
 			$this->menuSpeed = self::DEFAULT_MENU_SPEED;			// メニュー表示速度
 			$this->defaultNo = 0;			// デフォルトの項目番号
@@ -208,7 +202,6 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 				if ($ret){
 					$this->menuId	= $targetObj->menuId;		// メニューID
 					$name			= $targetObj->name;// 名前
-					$limitUser		= $targetObj->limitUser;					// ユーザを制限するかどうか
 					$this->menuType = $targetObj->menuType;			// メニュータイプ
 					$this->menuSpeed = $targetObj->menuSpeed;			// メニュー表示速度
 					$this->defaultNo = $targetObj->defaultNo;			// デフォルトの項目番号
@@ -240,9 +233,6 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 		// 画面にデータを埋め込む
 		$this->tmpl->addVar("item_name_visible", "name", $name);		// 名前
 		if (!empty($this->configId)) $this->tmpl->addVar("_widget", "id", $this->configId);		// 定義ID
-		$checked = '';
-		if ($limitUser) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "limit_user", $checked);	// ユーザを制限するかどうか
 		$this->tmpl->addVar("_widget", "default_no", $this->defaultNo);	// デフォルトの項目番号
 		$this->tmpl->addVar("_widget", "css_id",	$this->cssId);	// CSS用ID
 		$this->tmpl->addVar("_widget", "css",	$this->css);
@@ -470,7 +460,7 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 			
 			$defCount = 0;
 			if (!empty($id)){
-				$defCount = $this->sysDb->getPageDefCount($this->gEnv->getCurrentWidgetId(), $id);
+				$defCount = $this->_db->getPageDefCount($this->gEnv->getCurrentWidgetId(), $id);
 			}
 			$operationDisagled = '';
 			if ($defCount > 0) $operationDisagled = 'disabled';
@@ -526,13 +516,16 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 						$option = 'target="_blank"';
 						break;
 				}
+				// メニュー項目を作成
+				$name = $this->getCurrentLangString($row['md_name']);
+				if (empty($name)) continue;
 				
 				// ##### ツリーメニュー作成 #####
 				if ($row['md_type'] == 0){	// リンク項目のとき
-					$treeHtml .= '<li><a href="' . $linkUrl . '" ' . $option . '>' . $this->convertToDispString($row['md_name']) . '</a></li>' . M3_NL;
+					$treeHtml .= '<li><a href="' . $linkUrl . '" ' . $option . '>' . $this->convertToDispString($name) . '</a></li>' . M3_NL;
 				} else if ($row['md_type'] == 1){			// フォルダのとき
 					// サブメニュー作成
-					$treeHtml .= '<li><a href="#">' . $this->convertToDispString($row['md_name']) . '</a>' . M3_NL;
+					$treeHtml .= '<li><a href="#">' . $this->convertToDispString($name) . '</a>' . M3_NL;
 					
 					// 1階層目のときは、メニューの開閉を制御
 					$optionClass = '';
@@ -547,7 +540,7 @@ class admin_slide_menuWidgetContainer extends BaseAdminWidgetContainer
 					$treeHtml .= '</ul>' . M3_NL;
 					$treeHtml .= '</li>' . M3_NL;
 				} else if ($row['md_type'] == 2){			// テキストのとき
-					//$treeHtml .= '<li><span>' . $this->convertToDispString($row['md_name']) . '</span></li>' . M3_NL;
+					//$treeHtml .= '<li><span>' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
 				} else if ($row['md_type'] == 3){			// セパレータのとき
 					//$treeHtml .= '<li><span>' . '-----' . '</span></li>' . M3_NL;
 				}
