@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: link.php 1144 2008-10-27 10:09:22Z fishbone $
+ * @version    SVN: $Id: link.php 1151 2008-10-29 02:34:45Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C) 2003-2006 PukiWiki Developers Team
@@ -84,9 +84,7 @@ function links_update($page)
 	$rel_auto = array(); // オートリンクしている参照先
 	$links    = links_get_objects($page, TRUE);
 	foreach ($links as $_obj) {
-		if (! isset($_obj->type) || $_obj->type != 'pagename' ||
-		    $_obj->name == $page || $_obj->name == '')
-			continue;
+		if (! isset($_obj->type) || $_obj->type != 'pagename' || $_obj->name == $page || $_obj->name == '') continue;
 
 		if (is_a($_obj, 'Link_autolink')) { // 行儀が悪い
 			$rel_auto[] = $_obj->name;
@@ -170,6 +168,10 @@ function links_init()
 
 	$ref   = array(); // 参照元
 	foreach (get_existpages() as $page) {
+		// ページ名エラーチェック
+		$value = trim($page);
+		if (empty($value)) continue;
+		
 		//if ($page == $whatsnew) continue;
 		// キャッシュを作成しないページはとばす
 		if ($page == WikiConfig::getWhatsnewPage()) continue;
@@ -177,9 +179,7 @@ function links_init()
 		$rel   = array(); // 参照先
 		$links = links_get_objects($page);
 		foreach ($links as $_obj) {
-			if (! isset($_obj->type) || $_obj->type != 'pagename' ||
-			    $_obj->name == $page || $_obj->name == '')
-				continue;
+			if (! isset($_obj->type) || $_obj->type != 'pagename' || $_obj->name == $page || $_obj->name == '') continue;
 
 			$rel[] = $_obj->name;
 			if (! isset($ref[$_obj->name][$page]))
@@ -203,9 +203,11 @@ function links_init()
 		foreach ($arr as $ref_page=>$ref_auto)
 			fputs($fp, $ref_page . "\t" . $ref_auto . "\n");
 		fclose($fp);*/
+		$updateData = '';
 		foreach ($arr as $ref_page=>$ref_auto){
-			WikiPage::updatePageCacheRef($page, $ref_page . "\t" . $ref_auto . "\n");
+			$updateData .= $ref_page . "\t" . $ref_auto . "\n";
 		}
+		WikiPage::updatePageCacheRef($page, $updateData);
 	}
 }
 // modified for Magic3 by naoki on 2008/10/15
@@ -216,6 +218,10 @@ function links_add($page, $add, $rel_auto)
 	$rel_auto = array_flip($rel_auto);
 	
 	foreach ($add as $_page) {
+		// ページ名エラーチェック
+		$value = trim($_page);
+		if (empty($value)) continue;
+		
 		$all_auto = isset($rel_auto[$_page]);
 		$is_page  = is_page($_page);
 		$ref      = $page . "\t" . ($all_auto ? 1 : 0) . "\n";
@@ -233,6 +239,7 @@ function links_add($page, $add, $rel_auto)
 		foreach ($refPage as $line){
 			list($ref_page, $ref_auto) = explode("\t", rtrim($line));
 			if (empty($ref_page)) continue;
+			
 			if (! $ref_auto) $all_auto = FALSE;
 			if ($ref_page != $page) $ref .= $line;
 		}
@@ -255,6 +262,10 @@ function links_delete($page, $del)
 	if (PKWK_READONLY) return; // Do nothing
 
 	foreach ($del as $_page) {
+		// ページ名エラーチェック
+		$value = trim($_page);
+		if (empty($value)) continue;
+		
 		//$ref_file = CACHE_DIR . encode($_page) . '.ref';
 		//if (! file_exists($ref_file)) continue;
 		$refPage = WikiPage::getPageCacheRef($_page);
@@ -268,6 +279,7 @@ function links_delete($page, $del)
 		foreach ($refPage as $line) {
 			list($ref_page, $ref_auto) = explode("\t", rtrim($line));
 			if (empty($ref_page)) continue;
+			
 			if ($ref_page != $page) {
 				if (! $ref_auto) $all_auto = FALSE;
 				$ref .= $line;
